
<img align="left" width="340px" src="https://github.com/ftdot/pyrolog/blob/master/banner.png?raw=true" />
<h1><strong>🔥 Pyrolog</strong> <i>WIP</i></h1>
<p>Pretty logging — Pretty project</p>

---

[![Issues](https://img.shields.io/github/issues/ftdot/pyrolog?style=for-the-badge)](https://github.com/ftdot/pyrolog/issues)

---

### Contents

[![WIP](https://img.shields.io/badge/%23-Work_In_Progress-orange?style=for-the-badge)](#%EF%B8%8F-wip)

[![License](https://img.shields.io/badge/%23-License-blue?style=for-the-badge)](#-license)

---

## ☢️ WIP

**Work In Progress**. Currently available version `pyrolog v2.1.1-beta`.

You can install\update by using these commands:

```shell
$ pip install -U pyrolog
```

or 

```shell
$ pip3 install -U pyrolog
```

for linux.

> **Warning**
> 
> Beta version doesn't guarantee correct work.
> You can report any issue [there](https://github.com/ftdot/pyrolog/issues).

If you want to contribute: just fork, commit you changes and create PR [there](https://github.com/ftdot/pyrolog/pulls).
Don't forget to comment your changes while contributing!

### 📃 License

By copying, distributing and modification this library, you agree with
[GNU LGPL 2.1 Terms](https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html).
License is applies to all source files of the library.
Is the python files, reStructured files, etc.
License also provides NO WARRANTY for this library!

```
    Pyrolog. Pretty logging library
    Copyright (C) 2023  ftdot

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
    USA
```
